# tkpick
<a href="https://pypi.org/project/tkpick"><img src="https://img.shields.io/pypi/v/tkpick?style=flat"></a> <img src="https://img.shields.io/pypi/pyversions/tkpick?style=flat"> <img src="https://img.shields.io/pypi/l/tkpick"> <img src="https://img.shields.io/badge/style-black-black?style=flat">

Get pixel color using the cursor

![](demo.gif)

### Availability
Only GNU/Linux

## Installing
### pip (No auto-update)
Install via `pip`:
```
[sudo] pip install tkpick
```

## Usage
```sh
$ tkpick or Tkpick
```

or `Application Menu` > `Graphics` > `Tkpick`

## Shortcuts

Shortcut | Function
--- | ---
`Shift-c` | Copy color to clipboard
`Shift-a` | Open the about window
`Shift-q` | Close tool

## License
This project is licensed under the GPL-3.0 - see the [LICENSE](LICENSE) file for details